Struct diem_operational_tool::json_rpc::JsonRpcClientWrapper[][src]

pub struct JsonRpcClientWrapper { /* fields omitted */ }
A wrapper around JSON RPC for error handling

Implementations

This method returns all validator infos currently registered in the validator set of the Diem blockchain. If account is specified, only a single validator info is returned: the one that matches the given account.