Struct diem_operational_tool::json_rpc::JsonRpcClientWrapper [−][src]
pub struct JsonRpcClientWrapper { /* fields omitted */ }Expand description
A wrapper around JSON RPC for error handling
Implementations
pub fn submit_transaction(
&self,
transaction: SignedTransaction
) -> Result<TransactionContext, Error>
pub fn validator_config(
&self,
account: AccountAddress
) -> Result<ValidatorConfigResource, Error>
pub fn validator_set(
&self,
account: Option<AccountAddress>
) -> Result<Vec<ValidatorInfo>, Error>
pub fn validator_set(
&self,
account: Option<AccountAddress>
) -> Result<Vec<ValidatorInfo>, Error>
This method returns all validator infos currently registered in the validator set of the Diem blockchain. If account is specified, only a single validator info is returned: the one that matches the given account.
pub fn transaction_status(
&self,
account: AccountAddress,
sequence_number: u64
) -> Result<Option<VMStatusView>, Error>